@@ -132,8 +132,8 @@ int cholesky2(DoubleMatrix& matrix, int n, double toler)
 
 void chinv2(DoubleMatrix& matrix , int n)
      {
-     register double temp;
-     register int i,j,k;
+     double temp;
+     int i,j,k;
 
      /*
      ** invert the cholesky in the lower triangle
@@ -187,8 +187,8 @@ void chinv2(DoubleMatrix& matrix , int n)
 
 void chsolve2(const DoubleMatrix& matrix, int n, AVector& y)
      {
-     register int i,j;
-     register double temp;
+     int i,j;
+     double temp;
 
      /*
      ** solve Fb =y
@@ -683,31 +683,32 @@ Coxfit::computeResidualDeviance()
 // 03/07/2013: add offsets
 
 // just an R interface to the coxfit routine, for regression testing purposes.
+// [[Rcpp::export]]
 SEXP
-cpp_coxfit(SEXP R_interface)
+cpp_coxfit(SEXP R_survTimes, SEXP R_censInd, SEXP R_offsets, SEXP R_X, SEXP R_method)
 {
     // ---------------
     // get R objects:
 
-    // extract survival times
-    R_interface = CDR(R_interface);
-    SEXP R_survTimes = CAR(R_interface);
-
-    // censoring status
-    R_interface = CDR(R_interface);
-    SEXP R_censInd = CAR(R_interface);
-
-    // offsets
-    R_interface = CDR(R_interface);
-    SEXP R_offsets = CAR(R_interface);
-
-    // design matrix
-    R_interface = CDR(R_interface);
-    SEXP R_X= CAR(R_interface);
-
-    // and the tie method
-    R_interface = CDR(R_interface);
-    SEXP R_method = CAR(R_interface);
+    // // extract survival times
+    // R_interface = CDR(R_interface);
+    // SEXP R_survTimes = CAR(R_interface);
+    // 
+    // // censoring status
+    // R_interface = CDR(R_interface);
+    // SEXP R_censInd = CAR(R_interface);
+    // 
+    // // offsets
+    // R_interface = CDR(R_interface);
+    // SEXP R_offsets = CAR(R_interface);
+    // 
+    // // design matrix
+    // R_interface = CDR(R_interface);
+    // SEXP R_X= CAR(R_interface);
+    // 
+    // // and the tie method
+    // R_interface = CDR(R_interface);
+    // SEXP R_method = CAR(R_interface);
 
     // ---------------
     // unpack R objects:
